from setuptools import setup 

setup(name='gpam-stfdigital',
      version='0.1',
      description='Client for integrate service with STF Digital',
      url='https://supremotribunalfederal.gitlab.io/',
      author='GPAM',
      author_email='gpamunb@gmail.com',
      license='MIT',
      packages=[    
                'gpam-stfdigital'
                ],
     zip_safe=False)
